==> 0.2.zip: 0.2/src/kinugasa/game/test/Test.java <==
/*
 * The MIT License
 *
 * Copyright 2021 Dra.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package kinugasa.game.test;

import kinugasa.game.GameManager;
import kinugasa.game.GameOption;
import kinugasa.game.GameTimeManager;
import kinugasa.game.GraphicsContext;
import kinugasa.game.LockUtil;
import kinugasa.game.input.GamePadStatusMonitor;
import kinugasa.game.input.InputState;
import kinugasa.game.input.InputType;
import kinugasa.game.input.Keys;
import kinugasa.game.ui.FontModel;
import kinugasa.game.ui.SimpleTextLabelModel;
import kinugasa.game.ui.TextLabelSprite;
import kinugasa.resource.sound.SoundBuilder;

/**
 *
 * @vesion 1.0.0 - 2021/08/17_14:12:16<br>
 * @author Dra211<br>
 */
public class Test extends GameManager{

	
	public static void main(String[] args) {
		LockUtil.deleteAllLockFile();
		new Test().gameStart(args);
	}
	
	private Test(){
		super(GameOption.defaultOption().setCenterOfScreen());
	}

	@Override
	protected void startUp() {
		// Q[Jn1񂾂s
		new SoundBuilder("C:/users/owner/desktop/test.wav").builde().load().play();
	}
	GamePadStatusMonitor gps = new GamePadStatusMonitor();
	TextLabelSprite fps = new TextLabelSprite("FPS:", new SimpleTextLabelModel("FPS", FontModel.DEFAULT), 12, 12);

	@Override
	protected void dispose() {
		// Q[I1񂾂s
	}

	@Override
	protected void update(GameTimeManager gtm) {
		// ݒ肵FPSŎs
		if(InputState.getInstance().isPressed(Keys.ESCAPE, InputType.SINGLE)){
			gameExit();
		}
		fps.setText("FPS:" + gtm.getFPSStr());
		gps.update(InputState.getInstance().getGamePadState());
	}

	@Override
	protected void draw(GraphicsContext gc) {
		gps.draw(gc);
		fps.draw(gc);
	}
	
	
}

==> 02.1.zip: 02.1/src/kinugasa/game/test/Test.java <==
/*
 * The MIT License
 *
 * Copyright 2021 Dra.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package kinugasa.game.test;

import kinugasa.game.GameManager;
import kinugasa.game.GameOption;
import kinugasa.game.GameTimeManager;
import kinugasa.game.GraphicsContext;
import kinugasa.game.LockUtil;
import kinugasa.game.input.GamePadStatusMonitor;
import kinugasa.game.input.InputState;
import kinugasa.game.input.InputType;
import kinugasa.game.input.Keys;
import kinugasa.game.ui.FontModel;
import kinugasa.game.ui.SimpleTextLabelModel;
import kinugasa.game.ui.TextLabelSprite;
import kinugasa.resource.sound.SoundBuilder;

/**
 *
 * @vesion 1.0.0 - 2021/08/17_14:12:16<br>
 * @author Dra211<br>
 */
public class Test extends GameManager{

//	public static void main(String[] args) {
//		LockUtil.deleteAllLockFile();
//		new Test().gameStart(args);
//	}
	
	private Test(){
		super(GameOption.defaultOption().setCenterOfScreen());
	}

	@Override
	protected void startUp() {
	}

	@Override
	protected void dispose() {
	}

	@Override
	protected void update(GameTimeManager gtm) {
	}

	@Override
	protected void draw(GraphicsContext gc) {
	}
	
	
}
